@@ -1,6 +1,6 @@
 /*****************************************************************************
 ** QNapi
-** Copyright (C) 2008 Krzemin <pkrzemin@o2.pl>
+** Copyright (C) 2008-2009 Krzemin <pkrzemin@o2.pl>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -15,34 +15,12 @@
 #ifndef __MOVIEINFO__H__
 #define __MOVIEINFO__H__
 
-#include <QFile>
-#include <cstring>
-#include <cmath>
-
-struct MainAVIHeader
+struct MovieInfo
 {
-	int dwMicroSecPerFrame;
-	int dwMaxBytesPerSec;
-	int dwReserved1;
-	int dwFlags;
-	int dwTotalFrames;
-	int dwInitialFrames;
-	int dwStreams;
-	int dwSuggestedBufferSize;
-	int dwWidth;
-	int dwHeight;
-	int dwReserved[4];
-};
-
-const char RIFF_HEADER[4] = {'R','I','F','F'};
-
-class MovieInfo
-{
-	public:
-		int width, height, time;
-		float fps;
-		bool isErr;
-		MovieInfo(const QString & filename);
+    bool isFilled;
+    int width, height;
+    double frameRate;
+    double durationSecs;
 };
 
 #endif
