@@ -1,6 +1,6 @@
 /*****************************************************************************
 ** QNapi
-** Copyright (C) 2008 Krzemin <pkrzemin@o2.pl>
+** Copyright (C) 2008-2009 Krzemin <pkrzemin@o2.pl>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -29,21 +29,31 @@ class QNapiOpenDialog : public QFileDialog
 Q_OBJECT
 public:
 
-	enum FilterMode {
-		None, Movies, Subtitles
-	};
+    enum FilterMode {
+        None, Movies, Subtitles
+    };
 
-	QNapiOpenDialog( QWidget * parent = 0, const QString & caption = QString(),
-						const QString & init_path = QString(),
-						FilterMode filterMode = None );
+    QNapiOpenDialog(QWidget * parent = 0,
+                    const QString & caption = QString(),
+                    const QString & init_path = QString(),
+                    FilterMode filterMode = None);
 
-	bool selectFile();
-	bool selectFiles();
-	bool selectDirectory();
+    bool selectFile();
+    bool selectFiles();
+    bool selectDirectory();
+    
+#if defined(Q_OS_WIN) || defined(Q_OS_MAC)
+    QStringList selectedFiles() const;
+#endif
 
 private:
 
-	bool placeWindow();
+    bool placeWindow();
+
+#if defined(Q_OS_WIN) || defined(Q_OS_MAC)
+    QStringList files;
+#endif
+
 };
 
 #endif
