@@ -1,6 +1,6 @@
 /*****************************************************************************
 ** QNapi
-** Copyright (C) 2008 Krzemin <pkrzemin@o2.pl>
+** Copyright (C) 2008-2009 Krzemin <pkrzemin@o2.pl>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -15,6 +15,8 @@
 #ifndef __VERSION__H__
 #define __VERSION__H__
 
-#define QNAPI_VERSION "0.1.5"
+#define QNAPI_VERSION "0.1.9"
+#define QNAPI_DISPLAYABLE_VERSION "0.1.9"
+#define QNAPI_URL "http://qnapi.github.io"
 
 #endif
